@@ -12,10 +12,12 @@
  - Sortie :
 ---------------------------------------------*/
 function creeNouvGrp($nomGrp,$details) {
+	global $mysqli;
+	
 	if (trim($nomGrp)=="") return "Nom du groupe vide !";
-	if ($res=mysql_query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomGrp'")) {
-		if (mysql_num_rows($res)==0) {//le nom n'existe pas encore - on créé le groupe
-			mysql_query("INSERT INTO es_groupes SET nom='".trim($nomGrp)."',details='".trim($details)."'");
+	if ($res=$mysqli->query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomGrp'")) {
+		if ($res->num_rows==0) {//le nom n'existe pas encore - on créé le groupe
+			$mysqli->query("INSERT INTO es_groupes SET nom='".trim($nomGrp)."',details='".trim($details)."'");
 		} else return "Création impossible !<br/><br/>Le nom de groupe existe déjà...";
 	}
 	return '';
@@ -30,20 +32,22 @@ function creeNouvGrp($nomGrp,$details) {
  - Sortie :
 ---------------------------------------------*/
 function recupGrp($choix=0) {
+	global $mysqli;
+	
 	if ($choix==0) $leChoix1=$leChoix2='1';
 	else {
 		$leChoix1='groupe_ID='.$choix;
 		$leChoix2='ID_groupe='.$choix;
 	}
 	$tGrp=array();
-	if ($res=mysql_query("SELECT count(*),groupe_ID FROM es_grp_machines WHERE ".$leChoix1." GROUP BY groupe_ID")) {
-		while (list($_nb,$_grpID)=mysql_fetch_row($res)) {
+	if ($res=$mysqli->query("SELECT count(*),groupe_ID FROM es_grp_machines WHERE ".$leChoix1." GROUP BY groupe_ID")) {
+		while (list($_nb,$_grpID)=$res->fetch_row()) {
 			$tGrp2[$_grpID]['nb']=$_nb;
 		}
 	}
 
-	if ($res=mysql_query("SELECT ID_groupe,nom,details FROM es_groupes WHERE ".$leChoix2." ORDER BY nom")) {
-		while (list($_grpID,$_nom,$_details)=mysql_fetch_row($res)) {
+	if ($res=$mysqli->query("SELECT ID_groupe,nom,details FROM es_groupes WHERE ".$leChoix2." ORDER BY nom")) {
+		while (list($_grpID,$_nom,$_details)=$res->fetch_row()) {
 			$tGrp[]=array('id'=>$_grpID,'nom'=>$_nom,'details'=>$_details,'nb'=>((isset($tGrp2[$_grpID]['nb']))?$tGrp2[$_grpID]['nb']:0));
 		}
 	}
@@ -59,9 +63,11 @@ function recupGrp($choix=0) {
  - Sortie :
 ---------------------------------------------*/
 function recupCompoGrp($idGrp) {
+	global $mysqli;
+	
 	$tMach=array();
-	if ($res=mysql_query("SELECT es_machines.nom,machine_ID FROM es_machines,es_grp_machines WHERE machine_ID=ID_machine AND groupe_ID='".$idGrp."' ORDER BY es_machines.nom")) {
-		while (list($_nomM,$_machID)=mysql_fetch_row($res)) {
+	if ($res=$mysqli->query("SELECT es_machines.nom,machine_ID FROM es_machines,es_grp_machines WHERE machine_ID=ID_machine AND groupe_ID='".$idGrp."' ORDER BY es_machines.nom")) {
+		while (list($_nomM,$_machID)=$res->fetch_row()) {
 			$tMach[$_machID]=$_nomM;
 		}
 	}
@@ -77,11 +83,13 @@ function recupCompoGrp($idGrp) {
  - Sortie :
 ---------------------------------------------*/
 function recupMachines($idMach=0) {
+	global $mysqli;
+	
 	if ($idMach==0) $choixMachine='1';
 	else $choixMachine="ID_machine=$idMach";
 	$tMach=array();
-	if ($res=mysql_query("SELECT ID_machine,nom,ip,os FROM es_machines WHERE ".$choixMachine." ORDER BY nom")) {
-		while (list($_machID,$_nomM,$_ip,$_os)=mysql_fetch_row($res)) {
+	if ($res=$mysqli->query("SELECT ID_machine,nom,ip,os FROM es_machines WHERE ".$choixMachine." ORDER BY nom")) {
+		while (list($_machID,$_nomM,$_ip,$_os)=$res->fetch_row()) {
 			$tMach[$_machID]=array('nom'=>$_nomM,'ip'=>$_ip, 'os'=>$_os);
 		}
 	}
@@ -98,11 +106,13 @@ function recupMachines($idMach=0) {
 ---------------------------------------------*/
 
 function ajouteMachinesGroupe($idGroupe,$idMach){
+	global $mysqli;
+	
 	if (!is_array($idMach)) $idMach=array($idMach);
 	if (count($idMach)>0) foreach ($idMach as $_ajoutMachine) {
 		$query="INSERT INTO es_grp_machines SET groupe_ID='$idGroupe' , machine_ID='$_ajoutMachine'";
 		//echo $query.BRCR;
-		mysql_query($query);
+		$mysqli->query($query);
 	}
 }
 
@@ -116,11 +126,13 @@ function ajouteMachinesGroupe($idGroupe,$idMach){
 ---------------------------------------------*/
 
 function supprimeMachinesGroupe($idGroupe,$idMach){
+	global $mysqli;
+	
 	if (!is_array($idMach)) $idMach=array($idMach);
 	if (count($idMach)>0) foreach ($idMach as $_ajoutMachine) {
 		$query="DELETE FROM es_grp_machines WHERE groupe_ID='$idGroupe' AND machine_ID='$_ajoutMachine'";
 		//echo $query.BRCR;
-		mysql_query($query);
+		$mysqli->query($query);
 	}
 }
 
@@ -133,11 +145,12 @@ function supprimeMachinesGroupe($idGroupe,$idMach){
  - Sortie :
 ---------------------------------------------*/
 function majNomGroupe($choixG,$nomG,$detailsG) {
-
-	if ($res=mysql_query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomG'")) {
-		if (mysql_num_rows($res)==0) {//le nom n'existe pas encore - on créé le groupe
+	global $mysqli;
+	
+	if ($res=$mysqli->query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomG'")) {
+		if ($res->num_rows==0) {//le nom n'existe pas encore - on créé le groupe
 			$query="UPDATE es_groupes SET nom='$nomG',details='$detailsG' WHERE ID_groupe='$choixG'";
-			mysql_query($query);
+			$mysqli->query($query);
 		} else return "Modification du nom impossible !<br/><br/>Le nom de groupe existe déjà...";
 	}
 	return '';
@@ -153,8 +166,10 @@ function majNomGroupe($choixG,$nomG,$detailsG) {
  - Sortie :
 ---------------------------------------------*/
 function suppGrp($choixG) {
-	mysql_query("DELETE FROM es_grp_machines WHERE groupe_ID=".$choixG);
-	mysql_query("DELETE FROM es_groupes WHERE ID_groupe=".$choixG);
+	global $mysqli;
+	
+	$mysqli->query("DELETE FROM es_grp_machines WHERE groupe_ID=".$choixG);
+	$mysqli->query("DELETE FROM es_groupes WHERE ID_groupe=".$choixG);
 }
 
 /*------------------------------------------
@@ -166,6 +181,7 @@ function suppGrp($choixG) {
  - Sortie :
 ---------------------------------------------*/
 function majBaseMachines($tMach,$tMachASupprimer) {
+	global $mysqli;
 	if (!is_array($tMach) && !(is_array($tMachASupprimer))) return false;
 
 	//print_r($tMach);
@@ -177,21 +193,21 @@ function majBaseMachines($tMach,$tMachASupprimer) {
 		} else {
 			$query="UPDATE es_machines SET ip='".$_mach['ip']."',os='".$_mach['os']."' WHERE ID_machine='".$_mach['id']."'";
 		}
-		mysql_query($query);
+		$mysqli->query($query);
 	}
 
 	//on gère les machines à supprimer de la base
 	if (is_array($tMachASupprimer)) foreach ($tMachASupprimer as $_nomM=>$val) {
 		$_idM='0';
-		if ($res=mysql_query("SELECT ID_machine FROM es_machines WHERE nom='".$_nomM."'")) {
-			if (mysql_num_rows($res)>0) { //la machine portant ce nom existe
-				list($_idM)=mysql_fetch_row($res);
+		if ($res=$mysqli->query("SELECT ID_machine FROM es_machines WHERE nom='".$_nomM."'")) {
+			if ($res->num_rows>0) { //la machine portant ce nom existe
+				list($_idM)=$res->fetch_row();
 			}
 		}
 		$query="DELETE FROM es_machines WHERE ID_machine='".$_idM."'"; //supprime les machines
-		mysql_query($query);
+		$mysqli->query($query);
 		$query="DELETE FROM es_grp_machines WHERE machine_ID='".$_idM."'"; //supprime les machines dans les groupes
-		mysql_query($query);
+		$mysqli->query($query);
 	}
 }
 
@@ -328,14 +344,33 @@ function listeStations($fic,$stationselect) {
 	$id_fichier = fopen($fic,"r");
 	$contenu = fread($id_fichier, filesize($fic));
 	fclose($id_fichier);
+
 	$lignes = explode(PHP_EOL, $contenu);
+	//print_r($lignes);
 	foreach ($lignes as $ligne) {
 		if (trim($ligne)=="") continue;
 		$tabligne = explode(";",$ligne);
-		if (trim($tabligne[1])=="" || trim($tabligne[2])=="" || trim(strtolower($tabligne[2]))=="none") { //pb adresse IP ou adresse MAC
-			$nomsPb[] = $tabligne[0];
+		//print_r($tabligne);
+		/// V2.4.7 - OH - correction affichage lignes vides pour les entrées de copie_machines.db incomplètes
+		if (count($tabligne)==4) { //scribe <= 2.3
+			if (trim($tabligne[1])=="" || trim($tabligne[3])=="" || trim(strtolower($tabligne[3]))=="none") { //pb adresse IP ou adresse MAC
+				$noms[] = $nomsPb[] = $tabligne[0]." (adresse inconnue)";
+			} else $noms[] = $tabligne[0];
+			$noms[] = $tabligne[0];
+		} else { //scribe 2.5
+			if (trim($tabligne[0])=="") { //pb nom
+				$noms[] = $nomsPb[] = "(nom inconnu - ".$tabligne[1].")";
+				//$noms[] = "(nom inconnu - ".$tabligne[1].")";
+			}
+			else if (trim($tabligne[2])=="") { //pb adresse MAC
+				$noms[] = $nomsPb[] = $tabligne[0].'(adresse MAC inconnue)';
+			}
+			else if (trim($tabligne[1])=="") { //pb adresse IP
+				$noms[] = $nomsPb[] = $tabligne[0].'(adresse IP inconnue)';
+			}
+			else $noms[] = $tabligne[0];
 		}
-		$noms[] = $tabligne[0];
+		//$noms[] = $tabligne[0];
 		
 		if (isset($noms)) usort($noms, "strcasecmp");
 	}
@@ -343,7 +378,7 @@ function listeStations($fic,$stationselect) {
 		$desac=$txtPb="";
 		if (in_array($nom, $nomsPb)) {
 			$desac=" disabled";
-			$txtPb=" (adresse inconnue)";
+			//$txtPb=" (adresse inconnue)";
 		}
 		if (in_array($nom, $tL)) {
 			echo '<option selected="selected"'.$desac.'>'.$nom.$txtPb.'</option>';
@@ -351,6 +386,7 @@ function listeStations($fic,$stationselect) {
 			echo '<option'.$desac.'>'.$nom.$txtPb.'</option>';
 		}
 	}
+	/// V2.4.7 - OH
 }
 
 //modification du fichier ecoStations.txt
@@ -528,11 +564,11 @@ function tabplanstart($fichier,$_etat) {
 				$action = 'Activer';
 			}
 			echo '<h2>Planification '.$statut.' </h2>';
-			echo '<table style="width:760px;margin-bottom:15px;">';
+			echo '<table class="tabeco">';
 			echo '<th style="text-align:center;width:25px;"></th>';
 			echo '<th style="text-align:center;width:60px;">Horaire</th>';
 			echo '<th style="text-align:center;width:165px;">Jours</th>';
-			echo '<th>Stations à démarrer</th>';
+			echo '<th style="text-align:left;">Stations à démarrer</th>';
 			echo '</tr>';
  			foreach($lignes as $ligne_num => $ligne) { // on lit le tableau de façon séquentielle
 				//on n'insère pas la ligne d'entête
@@ -596,6 +632,27 @@ function tabplanstart($fichier,$_etat) {
 function copieMachinesdb() {
 	global $chemBaseAppli;
 	system("sudo ".$chemBaseAppli."/copieFicMachinesDB.pl");
+	$fic='config/copie_machines.db';
+	$id_fichier = fopen($fic,"r");
+	$contenu = fread($id_fichier, filesize($fic));
+	fclose($id_fichier);
+
+	$json = json_decode($contenu);
+	$content = "";
+	foreach($json as $lan => $devices) {
+		$nom = $devices->id;
+		foreach($devices->hwaddr_interfaces as $addmac){
+			$mac=$addmac;
+		}
+		foreach($devices->ipv4 as $ipv4){
+			$ip=$ipv4;
+		}
+		$content .= $nom.";".$ip.";".$mac."\n";
+	}
+	$id_fichier = fopen($fic,"w");
+	fwrite($id_fichier, $content);
+	fclose($id_fichier);
+	
 }
 
 //lance le script qui effectue les modif sur le cron à partir du fichier de config ecoStations.txt
